*******************************************************************
* Calculation of poverty PPPs
*
* Program   : 313_tornqvist_US$_50plw2.do
* Authors   : Angus Deaton, Princeton University
*             Olivier Dupriez, World Bank
* Version   : December 25, 2008
* Purpose   : Calculation of PPP conversion to US$ for Tornqvist,
*             with option "50 weighted and doubled poverty lines".
*             This is done for "rhetoric" purpose only.
*
* This Stata program is part of the following collection of Stata [.do] files:

* 
* Preparation of data files:
*   00_data_reshape_102_105
*   00_data_reshape_102_105_ALL
*
* Calculation of PPPs (NIPA and survey weights):
*   01a_ppp_nipa_102
*   01b_ppp_nipa_105
*   01c_ppp_nipa_102_ALL
*   01d_ppp_nipa_105_ALL
*   02_cpd_index_surveys
*   03_super_index_surveys
*
* Calculation of PPPPs and US$ index- Option "14 unweighted poverty lines":
*   104_tornqvist_approximation_14plnw
*   105_poverty_indexes_cpd_14plnw
*   106_poverty_indexes_cpd_sterrs_14plnw
*   107_poverty_indexes_fisher_14plnw
*   108_poverty_indexes_fisher_sterrs_14plnw
*   109_poverty_indexes_tornqvist_14plnw
*   110_poverty_indexes_tornqvist_sterrs_14plnw
*   111_cpd_USD_14plnw
*   112_fisher_USD_14plnw
*   113_tornqvist_USD_14plnw
*
* Calculation of PPPPs and US$ index- Option "50 weighted poverty lines":
*   204_tornqvist_approximation_50plw
*   205_poverty_indexes_cpd_50plw
*   206_poverty_indexes_cpd_sterrs_50plw
*   207_poverty_indexes_fisher_50plw
*   208_poverty_indexes_fisher_sterrs_50plw
*   209_poverty_indexes_tornqvist_50plw
*   210_poverty_indexes_tornqvist_sterrs_50plw
*   211_cpd_USD_50plw
*   212_fisher_USD_50plw
*   213_tornqvist_USD_50plw
*
* Calculation of PPPPs and US$ index- Option "50 weighted and doubled poverty lines":
*   304_tornqvist_approximation_50plw2
*   305_poverty_indexes_cpd_50plw2
*   306_poverty_indexes_cpd_sterrs_50plw2
*   307_poverty_indexes_fisher_50plw2
*   308_poverty_indexes_fisher_sterrs_50plw2
*   309_poverty_indexes_tornqvist_50plw2
*   310_poverty_indexes_tornqvist_sterrs_50plw2
*   311_cpd_USD_50plw2
*   312_fisher_USD_50plw2
*   313_tornqvist_USD_50plw2
*
* Star system for conversion to US$ for estimates from national accounts:
*   411_cpd_USD_NIPA102
*   412_fisher_USD_NIPA102
*   413_tornqvist_USD_NIPA102
*   511_cpd_USD_NIPA105
*   512_fisher_USD_NIPA105
*   513_tornqvist_USD_NIPA105
*
* Estimation of PPPs by regression model for non-ICP or non-survey countries:
*   601_regressions_PPP_estimates
*
****************************************************************************

version 9.2
#delimit;
set logtype text;
clear;
set mem 200m;
set matsize 6350;
set more off;
cap log close; 
clear;

* >> Enter directories where datafiles are found, and calculations have to be saved;
local dirdata  = "C:\Users\Olivier\_P4_Final\P4_Input_Files";
local dircalc  = "C:\Users\Olivier\_P4_Final\P4_Calculations";
cd "`dirdata'";

* >> Enter number of basic headings to be used in calculations;

local ng=102;

* >> Enter the Tornqvist international poverty line (at selected bandwidth) calculated with 06_poverty_indexes_tornqvist;

local ipl=12189.448;

* >> Enter the bandwidth to be used (1.0 / 0.5 / 0.1);
scalar hhh=0.5;

* >> Enter list of countries to be included in the calculation;
global cns= "us in bd bt kh cn fj id la my mv mn np pk ph lk th vn bj bf bi cm cv td cd cg ci dj et ga gm 
gh gn ke ls mg mw ml mr ma mz ne ng rw sn sl za sz tz tg ug ar bo br co py pe am az kz kg tj ye";

global cns_1= "in bd bt kh cn fj id la my mv mn np pk ph lk th vn bj bf bi cm cv td cd cg ci dj et ga gm 
gh gn ke ls mg mw ml mr ma mz ne ng rw sn sl za sz tz tg ug ar bo br co py pe am az kz kg tj ye";

*We count the number of countries;
global nc=0;
foreach iso of global cns {;
    global nc=$nc+1;
};
local nc1=$nc-1;
display "Number of countries is: " $nc;

* >> Enter name and location of input and log files;
local icprice  = "`dirdata'\bh_icp_prices_`ng'_Final_with_OECD.dta";
local prices_w = "`dirdata'\Global_prices_w_`ng'_Final.dta";
local usaprice = "`dirdata'\x_usa_`ng'.dta";
local expsurv  = "expsurv`ng'_";
local ppppest  = "`dircalc'\PPPP_Tornqvist_50plw2_`ng'_`nc1'.dta";
log using "`dircalc'\PPPP_to_USD_Tornqvist_50plw2.smcl", replace;

* We generate a matrix with the pppp estimates;
use "`ppppest'", clear;
* >> Select bandwidth (bwn): 1=1.0 / 2=0.5 / 3=0.1 ;


keep if bwn==2;
keep pppp;
mkmat *, mat(pppp);

* We generate a new data file with parities at basic heading level, all converted in a same currency (Indian Rp)  ;
* using Tornqvist PPPPs at the specified bandwidth;

* >> Select price variables to be used; 
use "`icprice'", replace;
keep p_us
     p_in p_bd p_bt p_kh p_cn p_fj p_id p_la p_my p_mv p_mn p_np p_pk p_ph p_lk p_th p_vn
     p_bj p_bf p_bi p_cm p_cv p_td p_cd p_cg p_ci p_dj p_et p_ga p_gm p_gh p_gn p_ke p_ls 
     p_mg p_mw p_ml p_mr p_ma p_mz p_ne p_ng p_rw p_sn p_sl p_za p_sz p_tz p_tg p_ug
     p_ar p_bo p_br p_co p_py p_pe p_am p_az p_kz p_kg p_tj p_ye;

* >> Edit this using the latest Tornqvist PPPP estimates for the selected bandwidth;
replace p_in=p_in/	1.000	;
replace p_bd=p_bd/	1.566	;
replace p_bt=p_bt/	1.125	;
replace p_kh=p_kh/	108.284	;
replace p_cn=p_cn/	0.262	;
replace p_fj=p_fj/	0.082	;
replace p_id=p_id/	260.997	;
replace p_la=p_la/	260.465	;
replace p_my=p_my/	0.126	;
replace p_mv=p_mv/	0.516	;
replace p_mn=p_mn/	33.856	;
replace p_np=p_np/	1.598	;
replace p_pk=p_pk/	1.447	;
replace p_ph=p_ph/	1.541	;
replace p_lk=p_lk/	2.597	;
replace p_th=p_th/	1.155	;
replace p_vn=p_vn/	380.186	;
replace p_bj=p_bj/	17.964	;
replace p_bf=p_bf/	16.481	;
replace p_bi=p_bi/	29.926	;
replace p_cm=p_cm/	20.208	;
replace p_cv=p_cv/	4.506	;
replace p_td=p_td/	22.569	;
replace p_cd=p_cd/	21.602	;
replace p_cg=p_cg/	25.127	;
replace p_ci=p_ci/	22.199	;
replace p_dj=p_dj/	8.223	;
replace p_et=p_et/	0.200	;
replace p_ga=p_ga/	29.999	;
replace p_gm=p_gm/	0.871	;
replace p_gh=p_gh/	324.470	;
replace p_gn=p_gn/	105.118	;
replace p_ke=p_ke/	2.293	;
replace p_ls=p_ls/	0.250	;
replace p_mg=p_mg/	54.291	;
replace p_mw=p_mw/	4.039	;
replace p_ml=p_ml/	19.274	;
replace p_mr=p_mr/	9.177	;
replace p_ma=p_ma/	0.353	;
replace p_mz=p_mz/	766.579	;
replace p_ne=p_ne/	18.936	;
replace p_ng=p_ng/	5.610	;
replace p_rw=p_rw/	17.554	;
replace p_sn=p_sn/	20.947	;
replace p_sl=p_sl/	104.860	;
replace p_za=p_za/	0.278	;
replace p_sz=p_sz/	0.254	;
replace p_tz=p_tz/	32.208	;
replace p_tg=p_tg/	19.449	;
replace p_ug=p_ug/	48.996	;
replace p_ar=p_ar/	0.084	;
replace p_bo=p_bo/	0.185	;
replace p_br=p_br/	0.102	;
replace p_co=p_co/	89.298	;
replace p_py=p_py/	149.048	;
replace p_pe=p_pe/	0.119	;
replace p_am=p_am/	11.978	;
replace p_az=p_az/	96.854	;
replace p_kz=p_kz/	3.147	;
replace p_kg=p_kg/	0.784	;
replace p_tj=p_tj/	0.058	;
replace p_ye=p_ye/	4.977	;

global cnb=1;
foreach iso of global cns {;
   ren p_`iso' p$cnb;
   gen lnp$cnb=log(p$cnb);
   mkmat lnp$cnb;
   mkmat p$cnb;
   global cnb=$cnb+1;
};

* Build weight matrix for USA (these are national accounts weights);
use "`usaprice'", clear;
keep x_us;
mkmat *, mat(wpov1);


* Build weight matrix for other countries (at the international poverty line);
drop _all;
scalar hhh=1;
global cno=2;
foreach iso of global cns_1 {;
   use `expsurv'`iso';
   drop if hh_totx==. | sx==. | hhs==0 | hhs==.;
   gen pce=hh_totx/hhs;
   keep x* mult pce sx;
   forvalues i=1(1)`ng' {;
      gen w`i'=x`i'/sx;
      drop x`i';
   };
   keep w* pce mult;
   save temp$cno, replace;
   global cno=$cno+1;
};

cap program drop mk_wpov;
program define mk_wpov;
   use temp`1', clear;
   gen lnx=log(pce);
   qui summ lnx [aw=mult];
   scalar hbw=`2'*r(sd);
   gen tau=abs(lnx-`3')/hbw;
   gen kwt=(15/(16*hbw))*(1-tau^2)^2;
   replace kwt=0 if tau >= 1;
   qui count if tau < 1;
   display "Country: " $cno " - Bandwidth: " hhh;
   display "No of observations in band is " r(N);
   display "Fraction of sample in band is " r(N)/_N;
   scalar nin_s=r(N);
   gen pwt=mult*kwt;
   drop mult;
   collapse w* [aweight=pwt];
   gen ct=1;
   reshape long w, i(ct) j(kgp);
   drop ct;
   sort kgp;
   mkmat w, matrix(`4');
   drop _all;
end;

global cno=2;
global aaa=1;
foreach iso of global cns_1 {; 
   scalar lnpl =ln(`ipl'*pppp[$aaa,1]); 
   mk_wpov "$cno" hhh lnpl "wpov$cno";
   global cno=$cno+1;
   global aaa=$aaa+1;
};


* Calculate the Tornqvist index;

matrix b=J($nc,$nc,0);
matrix uns=J($nc,1,1);

forvalues i=1(1)$nc {;
   forvalues j=1(1)$nc {;
      matrix aa=0.5*(wpov`i'+wpov`j')'*(lnp`j'-lnp`i');
      matrix b[`i',`j']=aa[1,1];
   };
};
matrix cc=b'*uns/$nc;
matrix aa=b[1,1..$nc]*uns/$nc;
matrix torns_1=cc+aa[1,1]*uns;
display "New Tornqvist indexes";
matrix list torns_1;

#delimit ;
matrix fis=J($nc-1,4,0);
local nc2=$nc-1;
forvalues i=1(1)`nc2' {;
   local j=`i'+1;
   matrix fis[`i',1]=exp(torns_1[`j',1]);
};

* We calculate the weighting coefficients;  
* The weights are the number of poor in each country divided by the total number of poor in all countries. ;

* Generate a matrix with the international poverty line expressed in local currency;
matrix plin=pppp*`ipl';

global lino=1;
display "Extrapolated population and nb of poor, and percentage of poor";
foreach pln of global cns_1 {;          
    use `expsurv'`pln', clear;
    gen pce=hh_totx/ hhsize;
    gen all=mult* hhsize;
    gen poor=mult* hhsize if pce<plin[$lino,1];
    collapse (sum) all poor;
    gen pcpoor=poor/all;
    mkmat *, mat(PovShr);
    mat list PovShr;
    matrix fis[$lino, 2]=PovShr[1,2];
    global lino=$lino+1;
};
global nbpoor=0;
forvalues i=1(1)`nc1' {;
    global nbpoor=$nbpoor+fis[`i',2];
};
forvalues i=1(1)`nc1' {;
    matrix fis[`i',3]=fis[`i',2]/$nbpoor;
};
* We verify that the total of the weights = 1;
global testw=0;
forvalues i=1(1)`nc1' {;
    global testw=$testw+fis[`i',3];
};
display "Sum of weights after recalculation is: " $testw;

* We weight these pppp estimates;
forvalues i=1(1)`nc1' {;
     matrix fis[`i',4]=fis[`i',1]*fis[`i',3];
};
mat list fis; 

* We calculate the weighted average of the pppp estimates to obtain the US$ pppp;
global ppppusa=0;
forvalues i=1(1)`nc1' {;
    global ppppusa=$ppppusa+fis[`i',4];
};

* Display final result;
display "The weighted average of Tornqvist PPPP estimates of [ref. currency] to US$ is: " $ppppusa;

scalar pp=`ipl';
scalar p4=$ppppusa;
scalar plus=(pp/p4)/365;

display "The international poverty line in US$ is: " plus " US$ per capita per day";

log close;