*******************************************************************
* Calculation of poverty PPPs
*
* Program   : 513_tornqvist_US$_NIPA105.do
* Authors   : Angus Deaton, Princeton University
*             Olivier Dupriez, World Bank
* Version   : December 25, 2008
* Purpose   : Calculation of PPP conversion to US$ for Tornqvist,
*             This is done for "rhetoric" purpose only.
*
* This Stata program is part of the following collection of Stata [.do] files:

* 
* Preparation of data files:
*   00_data_reshape_102_105
*   00_data_reshape_102_105_ALL
*
* Calculation of PPPs (NIPA and survey weights):
*   01a_ppp_nipa_102
*   01b_ppp_nipa_105
*   01c_ppp_nipa_102_ALL
*   01d_ppp_nipa_105_ALL
*   02_cpd_index_surveys
*   03_super_index_surveys
*
* Calculation of PPPPs and US$ index- Option "14 unweighted poverty lines":
*   104_tornqvist_approximation_14plnw
*   105_poverty_indexes_cpd_14plnw
*   106_poverty_indexes_cpd_sterrs_14plnw
*   107_poverty_indexes_fisher_14plnw
*   108_poverty_indexes_fisher_sterrs_14plnw
*   109_poverty_indexes_tornqvist_14plnw
*   110_poverty_indexes_tornqvist_sterrs_14plnw
*   111_cpd_USD_14plnw
*   112_fisher_USD_14plnw
*   113_tornqvist_USD_14plnw
*
* Calculation of PPPPs and US$ index- Option "50 weighted poverty lines":
*   204_tornqvist_approximation_50plw
*   205_poverty_indexes_cpd_50plw
*   206_poverty_indexes_cpd_sterrs_50plw
*   207_poverty_indexes_fisher_50plw
*   208_poverty_indexes_fisher_sterrs_50plw
*   209_poverty_indexes_tornqvist_50plw
*   210_poverty_indexes_tornqvist_sterrs_50plw
*   211_cpd_USD_50plw
*   212_fisher_USD_50plw
*   213_tornqvist_USD_50plw
*
* Calculation of PPPPs and US$ index- Option "50 weighted and doubled poverty lines":
*   304_tornqvist_approximation_50plw2
*   305_poverty_indexes_cpd_50plw2
*   306_poverty_indexes_cpd_sterrs_50plw2
*   307_poverty_indexes_fisher_50plw2
*   308_poverty_indexes_fisher_sterrs_50plw2
*   309_poverty_indexes_tornqvist_50plw2
*   310_poverty_indexes_tornqvist_sterrs_50plw2
*   311_cpd_USD_50plw2
*   312_fisher_USD_50plw2
*   313_tornqvist_USD_50plw2
*
* Star system for conversion to US$ for estimates from national accounts:
*   411_cpd_USD_NIPA102
*   412_fisher_USD_NIPA102
*   413_tornqvist_USD_NIPA102
*   511_cpd_USD_NIPA105
*   512_fisher_USD_NIPA105
*   513_tornqvist_USD_NIPA105
*
* Estimation of PPPs by regression model for non-ICP or non-survey countries:
*   601_regressions_PPP_estimates
*
****************************************************************************

version 9.2
#delimit;
set logtype text;
clear;
set mem 200m;
set matsize 6600;
set more off;
cap log close; 
clear;

* >> Enter directories where datafiles are found, and calculations have to be saved;
local dirdata  = "C:\Users\Olivier\_P4_Final\P4_Input_Files";
local dircalc  = "C:\Users\Olivier\_P4_Final\P4_Calculations";
cd "`dirdata'";

* >> Enter number of basic headings to be used in calculations;

local ng=105;

* >> Enter list of countries to be included in the calculation;
global cns= "us in bd bt kh cn fj id la my mv mn np pk ph lk th vn bj bf bi cm cv td cd cg ci dj et ga gm 
gh gn ke ls mg mw ml mr ma mz ne ng rw sn sl za sz tz tg ug ar bo br co py pe am az kz kg tj ye";

global cns_1= "in bd bt kh cn fj id la my mv mn np pk ph lk th vn bj bf bi cm cv td cd cg ci dj et ga gm 
gh gn ke ls mg mw ml mr ma mz ne ng rw sn sl za sz tz tg ug ar bo br co py pe am az kz kg tj ye";

*We count the number of countries;
global nc=0;
foreach iso of global cns {;
    global nc=$nc+1;
};
local nc1=$nc-1;
display "Number of countries is: " $nc;

* >> Enter name and location of input and log files;
local icprice  = "`dirdata'\bh_icp_prices_`ng'_Final_with_OECD.dta";
log using "`dircalc'\PPPP_to_USD_Tornqvist_NIPA105.smcl", replace;

* We generate a new data file with parities at basic heading level, all converted in a same currency (Indian Rp)  ;
* using Tornqvist PPPs at the specified bandwidth;

* >> Select price variables to be used; 
use "`icprice'", replace;
keep p_us
     p_in p_bd p_bt p_kh p_cn p_fj p_id p_la p_my p_mv p_mn p_np p_pk p_ph p_lk p_th p_vn
     p_bj p_bf p_bi p_cm p_cv p_td p_cd p_cg p_ci p_dj p_et p_ga p_gm p_gh p_gn p_ke p_ls 
     p_mg p_mw p_ml p_mr p_ma p_mz p_ne p_ng p_rw p_sn p_sl p_za p_sz p_tz p_tg p_ug
     p_ar p_bo p_br p_co p_py p_pe p_am p_az p_kz p_kg p_tj p_ye;

* >> Edit this using the Tornqvist NIPA105 PPP estimates;
replace p_in=p_in/	1	;
replace p_bd=p_bd/	1.612	;
replace p_bt=p_bt/	1.173	;
replace p_kh=p_kh/	102.619	;
replace p_cn=p_cn/	0.266	;
replace p_fj=p_fj/	0.103	;
replace p_id=p_id/	273.558	;
replace p_la=p_la/	245.11	;
replace p_my=p_my/	0.139	;
replace p_mv=p_mv/	0.676	;
replace p_mn=p_mn/	34.603	;
replace p_np=p_np/	1.642	;
replace p_pk=p_pk/	1.318	;
replace p_ph=p_ph/	1.539	;
replace p_lk=p_lk/	2.521	;
replace p_th=p_th/	1.114	;
replace p_vn=p_vn/	384.065	;
replace p_bj=p_bj/	17.567	;
replace p_bf=p_bf/	15.815	;
replace p_bi=p_bi/	30.564	;
replace p_cm=p_cm/	19.296	;
replace p_cv=p_cv/	5.39	;
replace p_td=p_td/	21.168	;
replace p_cd=p_cd/	19.938	;
replace p_cg=p_cg/	24.411	;
replace p_ci=p_ci/	21.142	;
replace p_dj=p_dj/	7.554	;
replace p_et=p_et/	0.197	;
replace p_ga=p_ga/	29.636	;
replace p_gm=p_gm/	0.714	;
replace p_gh=p_gh/	284.734	;
replace p_gn=p_gn/	98.178	;
replace p_ke=p_ke/	2.183	;
replace p_ls=p_ls/	0.233	;
replace p_mg=p_mg/	51.34	;
replace p_mw=p_mw/	3.814	;
replace p_ml=p_ml/	19.133	;
replace p_mr=p_mr/	8.42	;
replace p_ma=p_ma/	0.381	;
replace p_mz=p_mz/	791.792	;
replace p_ne=p_ne/	17.788	;
replace p_ng=p_ng/	5.037	;
replace p_rw=p_rw/	16.547	;
replace p_sn=p_sn/	19.749	;
replace p_sl=p_sl/	95.603	;
replace p_za=p_za/	0.304	;
replace p_sz=p_sz/	0.264	;
replace p_tz=p_tz/	31.4	;
replace p_tg=p_tg/	18.025	;
replace p_ug=p_ug/	49.896	;
replace p_ar=p_ar/	0.092	;
replace p_bo=p_bo/	0.178	;
replace p_br=p_br/	0.107	;
replace p_co=p_co/	83.003	;
replace p_py=p_py/	143.421	;
replace p_pe=p_pe/	0.117	;
replace p_am=p_am/	10.466	;
replace p_az=p_az/	96.387	;
replace p_kz=p_kz/	3.711	;
replace p_kg=p_kg/	0.684	;
replace p_tj=p_tj/	0.05	;
replace p_ye=p_ye/	5.528	;

global cnb=1;
foreach iso of global cns {;
   ren p_`iso' p$cnb;
   gen lnp$cnb=log(p$cnb);
   mkmat lnp$cnb;
   mkmat p$cnb;
   global cnb=$cnb+1;
};

* Build weight matrixes (these are national accounts weights);
drop _all;
global cno=1;
foreach iso of global cns {;
   use new_bh_nat_accounts_105.dta, clear;
   keep x_`iso';
   mkmat *, mat(wpov$cno);
   global cno=$cno+1;
};

* Calculate the Tornqvist index;

matrix b=J($nc,$nc,0);
matrix uns=J($nc,1,1);

forvalues i=1(1)$nc {;
   forvalues j=1(1)$nc {;
      matrix aa=0.5*(wpov`i'+wpov`j')'*(lnp`j'-lnp`i');
      matrix b[`i',`j']=aa[1,1];
   };
};
matrix cc=b'*uns/$nc;
matrix aa=b[1,1..$nc]*uns/$nc;
matrix torns_1=cc+aa[1,1]*uns;
display "New Tornqvist indexes";
matrix list torns_1;

#delimit ;
matrix fis=J($nc-1,4,0);
local nc2=$nc-1;
forvalues i=1(1)`nc2' {;
   local j=`i'+1;
   matrix fis[`i',1]=exp(torns_1[`j',1]);
};

* Add weighting coefficients (population share among total population of 4,315,624,705);  
matrix pop = 
0.253632573	\
0.035517713	\
0.000147606	\
0.003233717	\
0.302273735	\
0.000191872	\
0.051106854	\
0.001312419	\
0.005944211	\
6.84251E-05	\
0.000591803	\
0.006278038	\
0.03609489	\
0.019595347	\
0.004557394	\
0.014598793	\
0.019256749	\
0.00196734	\
0.003228585	\
0.001821009	\
0.004123424	\
0.000117435	\
0.002350902	\
0.013611134	\
0.000836461	\
0.004306376	\
0.000186348	\
0.017418799	\
0.000299074	\
0.000374692	\
0.005221726	\
0.002086061	\
0.008248853	\
0.000458991	\
0.004319789	\
0.003064699	\
0.002690477	\
0.000686599	\
0.006984553	\
0.004757753	\
0.003073527	\
0.032754489	\
0.002139619	\
0.002727378	\
0.00129446	\
0.010865734	\
0.000262071	\
0.008915945	\
0.001445578	\
0.00670753	\
0.00897834	\
0.002127621	\
0.043291707	\
0.010414666	\
0.001366813	\
0.006319888	\
0.000699241	\
0.001944527	\
0.003509816	\
0.001191832	\
0.00151779	\
0.00488821	;

forvalues i=1(1)`nc1' {;
   matrix fis[`i',2]=pop[`i',1];
   matrix fis[`i',3]=fis[`i',1]*fis[`i',2];
};

mat list fis; 

* We calculate the weighted average of the ppp estimates to obtain the US$ ppp;
global pppusa=0;
forvalues i=1(1)`nc1' {;
    global pppusa=$pppusa+fis[`i',3];
};

* Display final result;
display "The weighted average of Tornqvist PPP estimates of [ref. currency] to US$ is: " $pppusa;

scalar p4=$pppusa;
scalar plus=(570.1/p4)*(12/365);

display "The international poverty line in US$ is: " plus " US$ per capita per day";

log close;